@@ -10,9 +10,9 @@ use Dezi::Indexer::Doc;
 use Scalar::Util qw( blessed );
 use Data::Dump qw( dump );
 
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'set_parser_from_type' => ( is => 'rw', isa => Bool, default => sub {1} );
 has 'indexer' => (
@@ -47,25 +47,25 @@ Dezi::Aggregator - document aggregation base class
  package MyAggregator;
  use Moose;
  extends 'Dezi::Aggregator';
-
+ 
  sub get_doc {
     my ($self, $url) = @_;
-
+    
     # do something to create a Dezi::Indexer::Doc object from $url
-
+    
     return $doc;
  }
-
+ 
  sub crawl {
     my ($self, @where) = @_;
-
+    
     foreach my $place (@where) {
-
+       
        # do something to search $place for docs to pass to get_doc()
-
+       
     }
  }
-
+ 
  1;
 
 =head1 DESCRIPTION
@@ -81,7 +81,7 @@ of aggregators that crawl the filesystem and web, respectively.
 
 =head2 BUILD
 
-Set object flags per Dezi::Class API. These are also accessors,
+Set object flags per Dezi::Class API. These are also accessors, 
 and include:
 
 =over
@@ -221,9 +221,7 @@ sub swish_filter {
         }
     }
 
-    my $sfo = $self->swish_filter_obj;
-
-    if ( $sfo->can_filter( $doc->type ) ) {
+    if ( $self->swish_filter_obj->can_filter( $doc->type ) ) {
 
         if ( $self->debug ) {
             warn sprintf
@@ -235,7 +233,7 @@ sub swish_filter {
         my $content = $doc->content;
         my $url     = $doc->url;
         my $type    = $doc->type;
-        my $f       = $sfo->convert(
+        my $f       = $self->swish_filter_obj->convert(
             document     => \$content,
             content_type => $type,
             name         => $url
@@ -275,7 +273,7 @@ sub swish_filter {
                 "No filter applied to %s - cannot filter %s (parser %s)\n",
                 $doc->url, $doc->type, $doc->parser, );
             warn sprintf( " available filter: %s\n", $_ )
-                for $sfo->filter_list;
+                for $self->swish_filter_obj->filter_list;
         }
 
     }
@@ -381,7 +379,7 @@ Peter Karman, E<lt>perl@peknet.comE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -420,10 +418,10 @@ L<http://search.cpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2015 by Peter Karman
+Copyright 2008-2009 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
