@@ -9,9 +9,9 @@ use Class::Load ();
 use Types::Standard qw( Bool HashRef );
 use Dezi::Types qw( DeziIndexerConfig DeziInvIndex DeziFileOrCodeRef );
 use Dezi::ReplaceRules;
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -130,7 +130,7 @@ Hashref passed directly to indexer->new.
 
 =item invindex
 
-String or Path::Class::Dir pointing at index directory,
+String or Path::Class::Dir pointing at index directory, 
 or a L<Dezi::InvIndex> instance.
 
 =item filter
@@ -158,11 +158,7 @@ has 'invindex' => (
     isa    => DeziInvIndex,
     coerce => 1,
 );
-has 'filter' => (
-    is     => 'rw',
-    isa    => DeziFileOrCodeRef,
-    coerce => 1,
-);
+has 'filter' => ( is => 'rw', isa => DeziFileOrCodeRef );
 has 'test_mode' => ( is => 'rw', isa => Bool, default => 0 );
 
 # allow for short names. we map to class->new
@@ -349,7 +345,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -394,10 +390,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2014 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the GPL v2 or later.
 
 =head1 SEE ALSO
 
