@@ -12,9 +12,9 @@ use Dezi::InvIndex;
 use SWISH::3 qw( :constants );
 use Try::Tiny;
 
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'invindex' => (
     is     => 'rw',
@@ -67,7 +67,7 @@ Dezi::Indexer - base indexer class
     $indexer->process($doc);
  }
  $indexer->finish;
-
+ 
 =head1 DESCRIPTION
 
 Dezi::Indexer is a base class implementing the simplest of indexing
@@ -95,7 +95,7 @@ A Dezi::Indexer::Config object or file name.
 
 =item flush
 
-The number of indexed docs at which in-memory changes
+The number of indexed docs at which in-memory changes 
 should be written to disk.
 
 =item invindex
@@ -295,7 +295,7 @@ Peter Karman, E<lt>perl@peknet.comE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -334,10 +334,10 @@ L<http://search.cpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2015 by Peter Karman
+Copyright 2008-2009 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
