@@ -1,7 +1,7 @@
 package Dezi::Indexer::Config;
 use Moose;
 with 'Dezi::Role';
-use Types::Standard qw( Str HashRef );
+use Types::Standard qw( Str );
 use MooseX::Types::Path::Class;
 use Carp;
 use Config::General;
@@ -19,20 +19,17 @@ use overload(
     fallback => 1,
 );
 
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 # only a few explicitly named attributes.
 # everything else is through AUTOLOAD.
-has '_orig_args' => ( is => 'ro', isa => HashRef, default => sub { {} } );
 has 'file' => ( is => 'rw', isa => 'Path::Class::File', coerce => 1, );
 has 'swish3_config' => ( is => 'ro', isa => Str );
 
 my $XML = Search::Tools::XML->new;
 
-my %ReservedFieldNames = map { $_ => 1 } qw(uri title summary mtime);
-
 my %unique = map { $_ => 1 } qw(
     MetaNames
     PropertyNames
@@ -153,18 +150,18 @@ sub AUTOLOAD {
 
 =head1 NAME
 
-Dezi::Indexer::Config - read/write Indexer config files
+Dezi::Indexer::Config - read/write Swish-e config files
 
 =head1 SYNOPSIS
 
  use Dezi::Indexer::Config;
-
+ 
  my $config = Dezi::Indexer::Config->new;
  $config->write2();
  $config->read2('path/to/file.conf');
  $config->write3();
-
-
+ 
+ 
 =head1 DESCRIPTION
 
 The Dezi::Indexer::Config class reads and writes Swish-e 2.x configuration files,
@@ -172,7 +169,6 @@ and converts them to Swish3-style XML configuration format.
 
 See the Swish-e documentation for a list of configuration parameters.
 Each parameter has an accessor/mutator method as part of the Config object.
-L<http://swish-e.org/docs/swish-config.html>.
 
 B<NOTE:> Every config parameter can take either a scalar or an array ref as a value.
 In addition, you may append config values to any existing values by passing an additional
@@ -188,22 +184,22 @@ Example:
  # one two
  # red yellow
  # green blue
-
+ 
 
 =head1 METHODS
 
 =head2 new( I<params> )
 
-Instantiate a new Config object.
+Instantiate a new Config object. 
 Takes a hash of key/value pairs, where each key
-may be a configuration parameter.
+may be a Swish-e configuration parameter.
 
 Example:
 
  my $config = Dezi::Indexer::Config->new( DefaultContents => 'HTML*' );
-
+ 
  print "DefaultContents is ", $config->DefaultContents, "\n";
-
+ 
 =cut
 
 around BUILDARGS => sub {
@@ -214,7 +210,7 @@ around BUILDARGS => sub {
         return $class->$orig( file => $_[0] );
     }
     else {
-        return $class->$orig( @_, _orig_args => {@_} );
+        return $class->$orig(@_);
     }
 };
 
@@ -227,12 +223,6 @@ Internal method called by new().
 sub BUILD {
     my $self = shift;
 
-    # use our custom get/set methods on original args
-    my $orig = $self->_orig_args;
-    for my $k (keys %$orig) {
-        $self->$k( $orig->{$k} );
-    }
-
     $self->{swish3} = SWISH::3->new();
 
     if ( $self->file ) {
@@ -296,7 +286,6 @@ sub _set {
     my ( $key, $val, $append ) = @_;
 
     if ( $key eq 'file' or $key eq 'debug' ) {
-        confess "Moose should handle $key attribute";
         return $self->{$key} = $val;
     }
     elsif ( exists $unique{$key} ) {
@@ -366,12 +355,12 @@ Example:
  use Dezi::Indexer::Config;
  my $config = Dezi::Indexer::Config->new();
  my $parsed = $config->read2( 'my/file.cfg' );
-
+ 
  # should print same thing
  print $config->WordCharacters->[0], "\n";
  print $parsed->{WordCharacters}, "\n";
-
-
+ 
+ 
 =cut
 
 sub read2 {
@@ -429,7 +418,7 @@ Writes Swish-e version 2 compatible config file.
 If I<path/file> is omitted, a temp file will be
 written using File::Temp.
 
-If I<prog_mode> is true all config directives
+If I<prog_mode> is true all config directives 
 inappropriate for the -S prog mode in the Native::Indexer
 are skipped. The default is false.
 
@@ -572,7 +561,7 @@ sub stringify {
 
 sub _write_utf8 {
     my ( $self, $file, $buf ) = @_;
-    binmode $file, ':encoding(UTF-8)';
+    binmode $file, ':utf8';
     print {$file} $buf;
 }
 
@@ -678,7 +667,7 @@ equivalents.
  UndefinedMetaNames
  UndefinedXMLAttributes
  XMLClassAttributes
-
+        
 =cut
 
 sub ver2_to_ver3 {
@@ -1015,10 +1004,6 @@ KEY: for my $k ( sort keys %$config ) {
         $xml .= " <MetaNames>\n";
         for my $name ( sort keys %$metas ) {
             my $uname = to_utf8($name);
-            if ( exists $ReservedFieldNames{$uname} ) {
-                warn
-                    "'$uname' is a reserved field name and may clash at search time\n";
-            }
             $xml .= sprintf( "  <%s />\n",
                 $self->_make_tag( $uname, $metas->{$name} ) );
         }
@@ -1028,10 +1013,6 @@ KEY: for my $k ( sort keys %$config ) {
         $xml .= " <PropertyNames>\n";
         for my $name ( sort keys %$props ) {
             my $uname = to_utf8($name);
-            if ( exists $ReservedFieldNames{$uname} ) {
-                warn
-                    "'$uname' is a reserved field name and may clash at search time\n";
-            }
             $xml .= sprintf( "  <%s />\n",
                 $self->_make_tag( $uname, $props->{$name} ) );
         }
@@ -1130,7 +1111,7 @@ __END__
 
 =head1 CAVEATS
 
-IgnoreTotalWordCountWhenRanking defaults to 0
+IgnoreTotalWordCountWhenRanking defaults to 0 
 which is B<not> the default in Swish-e 2.x.
 
 =head1 AUTHOR
@@ -1140,7 +1121,7 @@ Peter Karman, E<lt>perl@peknet.comE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -1179,10 +1160,10 @@ L<http://search.cpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2015 by Peter Karman
+Copyright 2006-2009 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
