@@ -1,8 +1,7 @@
 package Dezi::Indexer::Doc;
 use Moose;
-use MooseX::XSAccessor;
 with 'Dezi::Role';
-use Types::Standard qw( Str HashRef Int InstanceOf Maybe );
+use Types::Standard qw( Str HashRef Int InstanceOf );
 use Dezi::Types qw( DeziUriStr DeziEpoch );
 use Carp;
 use Data::Dump qw( dump );
@@ -11,19 +10,18 @@ use overload(
     'bool'   => sub {1},
     fallback => 1,
 );
-use SWISH::3::Headers;
+use Dezi::Indexer::Headers;
 
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
-
-my $default_headers = SWISH::3::Headers->new();
+our $VERSION = '0.003';
 
 my ( $locale, $lang, $charset );
 {
 
     # inside a block to reduce impact on any regex
     use POSIX;
+    use locale;
 
     $locale = setlocale(POSIX::LC_CTYPE);
     ( $lang, $charset ) = split( m/\./, $locale );
@@ -36,20 +34,19 @@ has 'modtime' => (
     isa     => DeziEpoch,
     coerce  => 1,
     default => sub { time() },
-    lazy    => 1,
 );
 has 'type'    => ( is => 'rw', isa => Str );
-has 'parser'  => ( is => 'rw', isa => Maybe [Str], );
+has 'parser'  => ( is => 'rw', isa => Str );
 has 'content' => ( is => 'rw', isa => Str );
-has 'action'  => ( is => 'rw', isa => Maybe [Str], );
+has 'action'  => ( is => 'rw', isa => Str );
 has 'data'    => ( is => 'rw', isa => HashRef );
 has 'size'    => ( is => 'rw', isa => Int );
 has 'charset' => ( is => 'rw', isa => Str, default => sub {$charset} );
 has 'version' => ( is => 'rw', isa => Str, default => sub {3} );
 has 'headers' => (
     is       => 'rw',
-    isa      => InstanceOf ['SWISH::3::Headers'],
-    default  => sub {$default_headers},
+    isa      => InstanceOf ['Dezi::Indexer::Headers'],
+    default  => sub { Dezi::Indexer::Headers->new() },
     required => 1,
 );
 
@@ -63,25 +60,24 @@ Dezi::Indexer::Doc - Document object class for passing to Dezi::Indexer
 
   # subclass Dezi::Indexer::Doc
   # and override filter() method
-
+  
   package MyDoc;
-  use Moose;
-  extends 'Dezi::Indexer::Doc';
-
+  use base qw( Dezi::Indexer::Doc );
+  
   sub filter {
     my $doc = shift;
-
+    
     # alter url
     my $url = $doc->url;
     $url =~ s/my.foo.com/my.bar.org/;
     $doc->url( $url );
-
+    
     # alter content
     my $buf = $doc->content;
     $buf =~ s/foo/bar/gi;
     $doc->content( $buf );
   }
-
+  
   1;
 
 =head1 DESCRIPTION
@@ -133,7 +129,7 @@ A hashref.
 =item version
 
 Swish-e 2.x or Swish3 style headers. Value should be C<2> or C<3>.
-Default is C<3>.
+Default is C<2>.
 
 =back
 
@@ -157,7 +153,7 @@ being process()ed by the Indexer.
 
 The default is to do nothing.
 
-This method can also be set using the filter() callback in Dezi::App->new().
+This method can also be set using the filter() callback in Dezi->new().
 
 =cut
 
@@ -166,7 +162,7 @@ sub filter { }
 =head2 as_string
 
 Return the Doc object rendered as a scalar string, ready to be indexed.
-This will include the proper headers. See L<SWISH::3::Headers>.
+This will include the proper headers. See Dezi::Indexer::Headers.
 
 B<NOTE:> as_string() is also used if you use a Doc object as a string.
 Example:
@@ -179,11 +175,9 @@ Example:
 sub as_string {
     my $self = shift;
 
-    my $body = $self->content;
-
     # we ignore size() and let Headers compute it based on actual content()
     return $self->headers->head(
-        $body,
+        $self->content,
         {   url     => $self->url,
             modtime => $self->modtime,
             type    => $self->type,
@@ -191,7 +185,7 @@ sub as_string {
             parser  => $self->parser,
             version => $self->version,
         }
-    ) . $body;
+    ) . $self->content;
 
 }
 
@@ -208,7 +202,7 @@ Peter Karman, E<lt>perl@peknet.comE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -247,10 +241,10 @@ L<http://search.cpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2015 by Peter Karman
+Copyright 2008-2009 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
