@@ -7,9 +7,9 @@ use MooseX::Types::Path::Class;
 use Carp;
 use SWISH::3 qw( :constants );
 
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'invindex' => ( is => 'rw', isa => DeziInvIndex, required => 1 );
 has 'file' => ( is => 'ro', isa => 'Path::Class::File', coerce => 1, );
@@ -49,12 +49,12 @@ sub _build_data {
     my $s3config = $self->swish3_config;
 
     $self->{data} = {
-        SWISH_PROP()    => $s3config->get_properties->_as_hash,
-        SWISH_META()    => $s3config->get_metanames->_as_hash,
-        SWISH_MIME()    => $s3config->get_mimes->_as_hash,
-        SWISH_PARSERS() => $s3config->get_parsers->_as_hash,
-        SWISH_INDEX()   => $s3config->get_index->_as_hash,
-        SWISH_ALIAS()   => $s3config->get_aliases->_as_hash,
+        SWISH_PROP()    => $s3config->get_properties,
+        SWISH_META()    => $s3config->get_metanames,
+        SWISH_MIME()    => $s3config->get_mimes,
+        SWISH_PARSERS() => $s3config->get_parsers,
+        SWISH_INDEX()   => $s3config->get_index,
+        SWISH_ALIAS()   => $s3config->get_aliases,
     };
 
     # add any leftovers
@@ -144,7 +144,7 @@ Dezi::InvIndex::Header - read/write InvIndex metadata
  for my $key (keys %{ $meta->data }) {
     dump $meta->$key;
  }
-
+ 
 =head1 DESCRIPTION
 
 A Dezi::InvIndex::Header object represents the metadata for an
@@ -156,11 +156,7 @@ at this time.
 All the L<SWISH::3> constants are imported into this namespace,
 including:
 
-=over 4
-
-=item * SWISH_DOC_PROP_MAP
-
-=back
+=head2 SWISH_DOC_PROP_MAP
 
 =head1 METHODS
 
@@ -171,7 +167,7 @@ Default is C<swish.xml>.
 
 =head2 swish_header_file
 
-Alias for header_file(). For backwards compatibility with SWISH::Prog.
+Alias for header_file(). For backwards compatability with SWISH::Prog.
 
 =head2 BUILD
 
@@ -212,7 +208,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -257,10 +253,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2014 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the GPL v2 or later.
 
 =head1 SEE ALSO
 
