@@ -19,7 +19,7 @@ use Path::Class::File::Lockable;
 use Sys::Hostname qw( hostname );
 use Digest::MD5 ();
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'highlightable_fields' =>
     ( is => 'rw', isa => 'Bool', default => sub {0} );
@@ -107,32 +107,23 @@ sub _build_lucy_delegates {
     my $analyzers   = {};
     my $case_folder = Lucy::Analysis::CaseFolder->new;
     my $tokenizer   = Lucy::Analysis::RegexTokenizer->new;
-    my $multival_tokenizer
-        = Lucy::Analysis::RegexTokenizer->new(
-        pattern => '[^' . SWISH_TOKENPOS_BUMPER() . ']+' );
-
-    # mimic StringType fields that require case and/or multival parsing.
-    $analyzers->{store_lc} = Lucy::Analysis::PolyAnalyzer->new(
-        analyzers => [ $multival_tokenizer, $case_folder ] );
-    $analyzers->{store} = $multival_tokenizer;
 
     # stemming means we fold case and tokenize too.
     if ( $lang and $lang =~ m/^\w\w$/ ) {
         my $stemmer
             = Lucy::Analysis::SnowballStemmer->new( language => $lang );
         $analyzers->{fulltext_lc}
-            = Lucy::Analysis::PolyAnalyzer->new( analyzers =>
-                [ $multival_tokenizer, $case_folder, $tokenizer, $stemmer ] );
+            = Lucy::Analysis::PolyAnalyzer->new(
+            analyzers => [ $case_folder, $tokenizer, $stemmer ] );
+        $analyzers->{store_lc} = $case_folder;
         $analyzers->{fulltext} = Lucy::Analysis::PolyAnalyzer->new(
-            analyzers => [ $multival_tokenizer, $tokenizer, $stemmer ] );
+            analyzers => [ $tokenizer, $stemmer ] );
     }
     else {
-        $analyzers->{fulltext_lc}
-            = Lucy::Analysis::PolyAnalyzer->new(
-            analyzers => [ $multival_tokenizer, $case_folder, $tokenizer, ],
-            );
-        $analyzers->{fulltext} = Lucy::Analysis::PolyAnalyzer->new(
-            analyzers => [ $multival_tokenizer, $tokenizer ] );
+        $analyzers->{fulltext_lc} = Lucy::Analysis::PolyAnalyzer->new(
+            analyzers => [ $case_folder, $tokenizer, ], );
+        $analyzers->{store_lc} = $case_folder;
+        $analyzers->{fulltext} = $tokenizer;
     }
 
     # cache our objects for later
@@ -294,17 +285,22 @@ sub _get_lucy_field_type {
         }
 
         #warn "spec prop !sort $name";
-        my $analyzer_key = 'store';
         if ( $def->{ignore_case} ) {
-            $analyzer_key = 'store_lc';
-        }
 
-        $type = Lucy::Plan::FullTextType->new(
-            analyzer      => $analyzers->{$analyzer_key},
-            highlightable => $self->highlightable_fields,
-            sortable      => $def->{sortable},
-            boost         => $def->{bias} || 1.0,
-        );
+            # StringType has no analyzer
+            # so we must switch to FullTextType and
+            # use a case-folding-only analyzer.
+            $type = Lucy::Plan::FullTextType->new(
+                analyzer      => $analyzers->{store_lc},
+                highlightable => $self->highlightable_fields,
+                sortable      => $def->{sortable},
+                boost         => $def->{bias} || 1.0,
+            );
+        }
+        else {
+            $type
+                = Lucy::Plan::StringType->new( sortable => $def->{sortable} );
+        }
     }
 
     $self->debug
@@ -443,7 +439,7 @@ sub swish3_handler {
 
     # serialize the doc with our tokenpos_bump char
     for my $k ( keys %doc ) {
-        $doc{$k} = to_utf8( join( SWISH_TOKENPOS_BUMPER(), @{ $doc{$k} } ) );
+        $doc{$k} = to_utf8( join( "\003", @{ $doc{$k} } ) );
     }
 
     $self->debug and carp dump \%doc;
@@ -637,7 +633,7 @@ The libswish3 XML and HTML parsers will automatically treat a <title> tag as swi
 
 =item
 
-Things get complicated quickly when defining fields. Experiment with small test cases to arrive at the configuration that works best with your application.
+Things get complicated quickly when defining fields. Experiment with small test cases to arrive a the configuration that works best with your application.
 
 =back
 
@@ -648,7 +644,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -693,10 +689,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2014 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the GPL v2 or later.
 
 =head1 SEE ALSO
 
