@@ -22,9 +22,9 @@ use Sort::SQL;
 use Search::Query;
 use Search::Query::Dialect::Lucy;
 
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'find_relevant_fields' => ( is => 'rw', isa => Bool, default => sub {0} );
 has 'nfs_mode'             => ( is => 'rw', isa => Bool, default => sub {0} );
@@ -34,14 +34,14 @@ has 'nfs_mode'             => ( is => 'rw', isa => Bool, default => sub {0} );
 Dezi::Lucy::Searcher - Dezi Apache Lucy Searcher
 
 =head1 SYNOPSIS
-
+ 
  my $searcher = Dezi::Lucy::Searcher->new(
      invindex             => 'path/to/index',
      max_hits             => 1000,
      find_relevant_fields => 1,   # default: 0
      nfs_mode             => 1,   # default: 0
  );
-
+                
  my $results = $searcher->search( 'foo bar' );
  while (my $result = $results->next) {
      printf("%4d %s\n", $result->score, $result->uri);
@@ -65,18 +65,14 @@ recommends the switch to using Lucy::Search::Searcher directly.
 All the L<SWISH::3> constants are imported into this namespace,
 including:
 
-=over 4
-
-=item * SWISH_DOC_PROP_MAP
-
-=back
+=head2 SWISH_DOC_PROP_MAP
 
 =head1 METHODS
 
 Only new and overridden methods are documented here. See
 the L<Dezi::Searcher> documentation.
 
-=head2 BUILD
+=head2 BUILD 
 
 Called internally by new(). Additional parameters include:
 
@@ -156,10 +152,10 @@ sub _build_lucy {
             analyzer => $schema->fetch_analyzer($name)
         };
         if ( exists $metanames->{$name}
-            and defined $metanames->{$name}->{alias_for} )
+            and defined $metanames->{$name}->alias_for )
         {
             $fieldtypes{$name}->{alias_for}
-                = $metanames->{$name}->{alias_for};
+                = $metanames->{$name}->alias_for;
         }
     }
 
@@ -182,13 +178,13 @@ sub _build_lucy {
     else {
         $self->{qp} = $self->{_initial_qp};
     }
-
+    
     $self->debug and warn dump $self;
 
     return $self;
 }
 
-=head2 get_propnames
+=head2 get_propnames 
 
 Returns array ref of PropertyNames defined for the invindex.
 The array will not contain any alias names or reserved PropertyNames.
@@ -229,7 +225,7 @@ The B<order> param in I<opts> may be a Lucy::Search::SortSpec object.
 
 =item default_boolop
 
-The default Boolean connector for parsing I<query>. Valid values
+The default boolean connector for parsing I<query>. Valid values
 are B<AND> and B<OR>. The default is
 B<AND> (which is different than Lucy::QueryParser, but the
 same as Swish-e).
@@ -269,8 +265,8 @@ sub search {
         $parsed_query = $self->qp->parse($query)
             or confess "Invalid query: " . $self->qp->error;
     }
-    elsif ( !$query->isa('Search::Query::Dialect') ) {
-        confess "query must be a string or a Search::Query::Dialect object";
+    elsif ( !$query->isa('Search::Tools::Dialect') ) {
+        confess "query must be a string or a Search::Tools::Dialect object";
     }
 
     my %hits_args = (
@@ -380,12 +376,9 @@ sub search {
         dump( $hits_args{query}->dump() ),
         dump( \%hits_args )
         );
-    my $compiler = $hits_args{query}->make_compiler(
-        searcher => $lucy,
-        boost    => 0,
-    );
-    my $hits    = $lucy->hits(%hits_args);
-    my $results = Dezi::Lucy::Results->new(
+    my $compiler = $hits_args{query}->make_compiler( searcher => $lucy );
+    my $hits     = $lucy->hits(%hits_args);
+    my $results  = Dezi::Lucy::Results->new(
         hits                 => $hits->total_hits + 0,
         payload              => $hits,
         query                => $parsed_query,
@@ -532,7 +525,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -577,10 +570,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2014 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the GPL v2 or later.
 
 =head1 SEE ALSO
 
