@@ -5,10 +5,9 @@ use Scalar::Util qw( blessed );
 use Carp;
 use Data::Dump qw( dump );
 use Text::ParseWords;
-use Try::Tiny;
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'rules' => ( is => 'rw', isa => 'ArrayRef' );
 
@@ -47,7 +46,7 @@ in a Dezi::Indexer::Config object or config file.
 Constructor for new ReplaceRules object. I<rules> should be an array
 of strings as defined in
 L<http://swish-e.org/docs/swish-config.html#replacerules>.
-
+ 
 =head2 BUILDARGS
 
 Internal method. Allows for single argument to new().
@@ -154,12 +153,8 @@ sub apply {
         if ( $action eq 'replace' ) {
             my $b = $target->{before};
             my $a = $target->{after};
-            try {
-                $str =~ s/$b/$a/g;
-            }
-            catch {
-                die "Bad rule: $orig ($_)";
-            };
+            $str =~ s/$b/$a/g;
+            die "Bad rule: $orig ($@)" if $@;
         }
         if ( $action eq 'regex' ) {
             my $d    = $target->{delim};
@@ -169,12 +164,8 @@ sub apply {
             my $code = "\$str =~ s/$b/$a/$o";
 
             #warn "code='$code'\n";
-            try {
-                eval "$code";
-            }
-            catch {
-                die "Bad rule: $orig ($_)";
-            }
+            eval "$code";
+            die "Bad rule: $orig ($@)" if $@;
         }
 
         #warn "$orig applied to '$str'\n";
@@ -195,7 +186,7 @@ Peter Karman, E<lt>perl@peknet.comE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-swish-prog at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
@@ -234,10 +225,10 @@ L<http://search.cpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2011 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
