@@ -3,9 +3,9 @@ use Moose;
 use MooseX::StrictConstructor;
 with 'Dezi::Role';
 use Carp;
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'doc'          => ( is => 'ro', isa => 'Object',  required => 1, );
 has 'score'        => ( is => 'ro', isa => 'Num',     required => 1 );
@@ -16,7 +16,7 @@ has 'property_map' => ( is => 'ro', isa => 'HashRef', required => 1 );
 Dezi::Result - abstract result class
 
 =head1 SYNOPSIS
-
+                
  my $results = $searcher->search( 'foo bar' );
  while (my $result = $results->next) {
      printf("%4d %s\n", $result->score, $result->uri);
@@ -42,20 +42,12 @@ Returns the ranking score for the Result.
 
 =head2 uri
 
-URL or filepath to document.
-
 =head2 mtime
 
-Last modified date of document.
-
 =head2 title
 
-Document title.
-
 =head2 summary
 
-Description of document.
-
 =head2 swishdocpath
 
 Alias for uri().
@@ -115,28 +107,6 @@ sub get_property {
     return $self->doc->property($propname);
 }
 
-=head2 get_property_array( I<property> )
-
-Returns the stored value for I<property> for the Result. Unlike
-get_property(), the value is always an arrayref, split
-on the libswish3 multi-value character.
-
-Example:
-
- my $val    = $result->get_property('foo');       # "green\003blue"
- my $arrval = $result->get_property_array('foo'); # ['green', 'blue']
-
-Note that return value will *always* be an arrayref, even if
-the original value does not contain a multi-value character.
-
-=cut
-
-sub get_property_array {
-    my $self = shift;
-    my $val  = $self->get_property(@_);
-    return [ split( /\003/, $val ) ];
-}
-
 =head2 property_map
 
 Set by the parent Results, a hashref of property aliases to real names.
@@ -157,7 +127,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -202,10 +172,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2014 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the GPL v2 or later.
 
 =head1 SEE ALSO
 
