@@ -3,9 +3,9 @@ use Moose;
 with 'Dezi::Role';
 use Carp;
 use Types::Standard qw( Int ArrayRef Str Maybe );
-use namespace::autoclean;
+use namespace::sweep;
 
-our $VERSION = '0.014_02';
+our $VERSION = '0.003';
 
 has 'start' => (
     is      => 'rw',
@@ -79,7 +79,7 @@ and an upper limit.
 
 =item default_boolop
 
-The default Boolean connector for parsing I<query>. Valid values
+The default boolean connector for parsing I<query>. Valid values
 are B<AND> and B<OR>. The default is
 B<AND> (which is different than Lucy::QueryParser, but the
 same as Swish-e).
@@ -93,7 +93,7 @@ Peter Karman, E<lt>karpet@dezi.orgE<gt>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-dezi-app at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dezi-App>.  
 I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
@@ -138,10 +138,10 @@ L<https://metacpan.org/dist/Dezi-App/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2015 by Peter Karman
+Copyright 2014 by Peter Karman
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the terms of the GPL v2 or later.
 
 =head1 SEE ALSO
 
